# Python InfraFlow CDK
A convention first library for defining event based and microservice architectures quickly and efficiently using premade patterns.

Just install an import

Other things to use with this library:
- AWS CDK
- To use Flask, Falcon, Django, or other UWSGI frameworks with CDK and Lambda: https://github.com/slank/awsgi